#
# spec file for package cross-sparc-binutils
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cross-sparc-binutils
ExcludeArch:    sparc
%define cross 1
%define TARGET sparc
BuildRequires:  bison
BuildRequires:  dejagnu
BuildRequires:  flex
BuildRequires:  gcc-c++
# for the testsuite
%if 0%{suse_version} >= 1210
BuildRequires:  glibc-devel-static
%endif
%if 0%{suse_version} > 1220
BuildRequires:  makeinfo
%endif
# for some gold tests
BuildRequires:  bc
%if 0%{suse_version} > 1110
BuildRequires:  zlib-devel-static
%else
BuildRequires:  zlib-devel
%endif
Version:        2.26.1
Release:        8.1
#
# RUN_TESTS
%define run_tests %(test ! -f %_sourcedir/RUN_TESTS ; echo $?)
# check the vanilla binutils, with no patches applied
# TEST_VANILLA
%define test_vanilla %(test ! -f %_sourcedir/TEST_VANILLA ; echo $?)
#
# handle test suite failures
#
%ifarch alpha %arm aarch64 hppa mips sh4 %sparc
%define	make_check_handling	true
%else
# XXX check again
# XXX disabled because gold is seriously broken for now
%define	make_check_handling	true
%endif
# let make check fail anyway if RUN_TESTS was requested
%if %{run_tests}
%define	make_check_handling	false
%endif
# handle all binary object formats supported by SuSE (and a few more)
%ifarch %ix86 %arm aarch64 ia64 ppc ppc64 ppc64le s390 s390x x86_64
%define build_multitarget 1
%else
%define build_multitarget 0
%endif
%define target_list aarch64 alpha armv5l armv6l armv7l armv8l hppa hppa64 i686 ia64 m68k mips powerpc powerpc64 powerpc64le s390 s390x sh4 sparc sparc64 x86_64
#
#
#
Url:            http://www.gnu.org/software/binutils/
PreReq:         %{install_info_prereq}
# bug437293
%ifarch ppc64
Obsoletes:      binutils-64bit
%endif
#
%define binutils_version %(echo %version | sed 's/\\.[0-9]\\{8\\}$//')
Summary:        GNU Binutils
License:        GFDL-1.3 and GPL-3.0+
Group:          Development/Tools/Building
Source:         binutils-%{binutils_version}.tar.bz2
Source1:        pre_checkin.sh
Source2:        README.First-for.SuSE.packagers
Source3:        baselibs.conf
#Patch:          binutils-2.26-branch.diff
Patch3:         binutils-skip-rpaths.patch
Patch4:         s390-biarch.diff
Patch5:         x86-64-biarch.patch
Patch6:         unit-at-a-time.patch
Patch7:         ld-dtags.diff
Patch8:         ld-relro.diff
Patch9:         testsuite.diff
Patch10:        enable-targets-gold.diff
Patch11:        use-hashtype-both-by-default.diff
Patch12:        s390-pic-dso.diff
Patch14:        binutils-build-as-needed.diff
Patch18:        gold-depend-on-opcodes.diff
Patch22:        binutils-bfd_h.patch
Patch34:        aarch64-common-pagesize.patch
Patch35:        gold-relocate-tls.patch
Patch90:        cross-avr-nesc-as.patch
Patch92:        cross-avr-omit_section_dynsym.patch
Patch93:        cross-avr-size.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         update-alternatives

%description
C compiler utilities: ar, as, gprof, ld, nm, objcopy, objdump, ranlib,
size, strings, and strip. These utilities are needed whenever you want
to compile a program or kernel.


%package gold
Summary:        The gold linker
License:        GPL-3.0+
Group:          Development/Tools/Building
Requires:       binutils = %{version}-%{release}
PreReq:         update-alternatives
%if 0%{suse_version} > 1100
%if 0%{!?cross:1}
%define gold_archs %ix86 aarch64 %arm x86_64 ppc ppc64 ppc64le %sparc
%endif
%endif

%description gold
gold is an ELF linker.	It is intended to have complete support for ELF
and to run as fast as possible on modern systems.  For normal use it is
a drop-in replacement for the older GNU linker.

%package devel
Summary:        GNU binutils (BFD development files)
License:        GPL-3.0+
Group:          Development/Libraries/C and C++
Requires:       binutils = %{version}-%{release}
Requires:       zlib-devel
Provides:       binutils:/usr/include/bfd.h

%description devel
This package includes header files and static libraries necessary to
build programs which use the GNU BFD library, which is part of
binutils.


%ifarch %arm
%define HOST %{_target_cpu}-suse-linux-gnueabi
%else
%define HOST %(echo %{_target_cpu} | sed -e "s/parisc/hppa/" -e "s/i.86/i586/" -e "s/ppc/powerpc/" -e "s/sparc64v.*/sparc64/" -e "s/sparcv.*/sparc/")-suse-linux
%endif 
%define DIST %(echo '%distribution' | sed 's/ (.*)//')

%prep
echo "make check will return with %{make_check_handling} in case of testsuite failures."
%setup -q -n binutils-%{binutils_version}
# Patch is outside test_vanilla because it's supposed to be the
# patch bringing the tarball to the newest upstream version
#%patch -p1
%if !%{test_vanilla}
%patch3
%patch4
%patch5
%patch6
%patch7 -p1
%patch8
%patch9
%patch10
%if "%{TARGET}" != "mips"
# The MIPS ABI is incompatible with .gnu.hash, so don't
# use it there
%patch11
%patch12
%endif
%patch14
%patch18
%patch22
%patch34 -p1
%patch35 -p1
%if "%{TARGET}" == "avr"
cp gas/config/tc-avr.h gas/config/tc-avr-nesc.h
%patch90
%patch92
%patch93
%endif
#
# test_vanilla
%endif
%if 0%{?qemu_user_space_build}
# Work around bug in qemu (make: execvp: /bin/sh: Argument list too long)
sed -i 's/\.EXPORT_ALL_VARIABLES:/#&/' gold/testsuite/Makefile.{am,in}
%endif

%build
sed -i -e '/BFD_VERSION_DATE/s/$/-%(echo %release | sed 's/\.[0-9]*$//')/' bfd/version.h
RPM_OPT_FLAGS="$RPM_OPT_FLAGS -Wno-error"
%if 0%{!?cross:1}
# Building native binutils
echo "Building native binutils." 
%if %build_multitarget
EXTRA_TARGETS="%(printf ,%%s-suse-linux %target_list)"
EXTRA_TARGETS="$EXTRA_TARGETS,powerpc-macos,powerpc-macos10,spu-elf,x86_64-pep"
%else
EXTRA_TARGETS=
%ifarch sparc
EXTRA_TARGETS="$EXTRA_TARGETS,sparc64-suse-linux"
%endif
%ifarch ppc
EXTRA_TARGETS="$EXTRA_TARGETS,powerpc64-suse-linux"
%endif
%ifarch s390
EXTRA_TARGETS="$EXTRA_TARGETS,s390x-suse-linux"
%endif
%ifarch s390x
EXTRA_TARGETS="$EXTRA_TARGETS,s390-suse-linux"
%endif
%ifarch %ix86
EXTRA_TARGETS="$EXTRA_TARGETS,x86_64-suse-linux"
%endif
%ifarch ppc ppc64 ppc64le
EXTRA_TARGETS="$EXTRA_TARGETS,spu-elf"
%endif
%ifarch %arm
EXTRA_TARGETS="$EXTRA_TARGETS,arm-suse-linux-gnueabi"
%endif
%ifarch aarch64
EXTRA_TARGETS="$EXTRA_TARGETS,aarch64-suse-linux"
%endif
%endif
# Normally we'd like to add --enable-deterministic-archives
# here (which by default makes uid/mtime be zero for archive
# members), to increase chances of getting a reproducable build
# But this breaks Makefile rules when directly accessing archives:
# rebuilding the same archive from unchanged .o files recreates
# it, because timestamps in the .a are 0, unequal to the actual timestamp
# of the .o files :-/
%define common_flags CFLAGS="${RPM_OPT_FLAGS}" CXXFLAGS="${RPM_OPT_FLAGS}" \\\
	--prefix=%{_prefix} --libdir=%{_libdir} \\\
	--infodir=%{_infodir} --mandir=%{_mandir} \\\
	--with-bugurl=http://bugs.opensuse.org/ \\\
	--with-pkgversion="GNU Binutils; %{DIST}" \\\
	--with-separate-debug-dir=%{_prefix}/lib/debug \\\
	--with-pic --build=%{HOST}
mkdir build-dir
cd build-dir
../configure %common_flags \
	${EXTRA_TARGETS:+--enable-targets="${EXTRA_TARGETS#,}"} \
	--enable-plugins \
%ifarch %gold_archs
	--enable-gold \
	--enable-threads \
%endif
%if %{suse_version} <= 1320
	--disable-x86-relax-relocations \
%endif
	--enable-shared
make %{?_smp_mflags} all-bfd TARGET-bfd=headers
# force reconfiguring (???)
rm bfd/Makefile
make %{?_smp_mflags}

%else
# building cross-TARGET-binutils
echo "Building cross binutils." 
mkdir build-dir
cd build-dir
EXTRA_TARGETS=
%if "%{TARGET}" == "sparc"
EXTRA_TARGETS="$EXTRA_TARGETS,sparc64-suse-linux"
%endif
%if "%{TARGET}" == "powerpc"
EXTRA_TARGETS="$EXTRA_TARGETS,powerpc64-suse-linux"
%endif
%if "%{TARGET}" == "s390"
EXTRA_TARGETS="$EXTRA_TARGETS,s390x-suse-linux"
%endif
%if "%{TARGET}" == "s390x"
EXTRA_TARGETS="$EXTRA_TARGETS,s390-suse-linux"
%endif
%if "%{TARGET}" == "i586"
EXTRA_TARGETS="$EXTRA_TARGETS,x86_64-suse-linux"
%endif
%if "%{TARGET}" == "hppa"
EXTRA_TARGETS="$EXTRA_TARGETS,hppa64-suse-linux"
%endif
%if "%{TARGET}" == "arm"
EXTRA_TARGETS="$EXTRA_TARGETS,arm-suse-linux-gnueabi"
%endif
%if "%{TARGET}" == "aarch64"
EXTRA_TARGETS="$EXTRA_TARGETS,aarch64-suse-linux"
%endif
%if "%{TARGET}" == "avr" || "%{TARGET}" == "spu"
%define TARGET_OS %{TARGET}
%else
%if "%{TARGET}" == "epiphany" || "%{TARGET}" == "rx"
%define TARGET_OS %{TARGET}-elf
%else
%if "%{TARGET}" == "arm"
%define TARGET_OS %{TARGET}-suse-linux-gnueabi
%else
%define TARGET_OS %{TARGET}-suse-linux
%endif
%endif
%endif
../configure CFLAGS="${RPM_OPT_FLAGS}" \
  --prefix=%{_prefix} \
  --with-bugurl=http://bugs.opensuse.org/ \
  --with-pkgversion="GNU Binutils; %{DIST}" \
  --disable-nls \
%if %{suse_version} <= 1320
  --disable-x86-relax-relocations \
%endif
  --build=%{HOST} --target=%{TARGET_OS} \
%if "%{TARGET}" == "spu"
  --with-sysroot=/usr/spu \
%else
  --with-sysroot=%{_prefix}/%{TARGET_OS}/sys-root \
%endif
  ${EXTRA_TARGETS:+--enable-targets="${EXTRA_TARGETS#,}"}
make %{?_smp_mflags} all-bfd TARGET-bfd=headers
# force reconfiguring
rm bfd/Makefile
make %{?_smp_mflags}
%if "%{TARGET}" == "avr"
# build an extra nesC version because nesC requires $'s in identifiers
cp -a gas gas-nesc
echo '#include "tc-%{TARGET}-nesc.h"' > gas-nesc/targ-cpu.h
make -C gas-nesc clean
make -C gas-nesc %{?_smp_mflags}
%endif
%endif

%check
unset SUSE_ASNEEDED
cd build-dir
%if 0%{?cross:1}
make -k check CFLAGS="-O2 -g" CXXFLAGS="-O2 -g" || %{make_check_handling}
%else
make -k check CFLAGS="$RPM_OPT_FLAGS -Wno-unused -Wno-unprototyped-calls" || :
%endif

%install
cd build-dir
%if 0%{!?cross:1}
# installing native binutils
%ifarch %gold_archs
make DESTDIR=$RPM_BUILD_ROOT install-gold
ln -sf ld.gold $RPM_BUILD_ROOT%{_bindir}/gold
%endif
make DESTDIR=$RPM_BUILD_ROOT install-info install
make -C gas/doc DESTDIR=$RPM_BUILD_ROOT install-info-am install-am
make DESTDIR=$RPM_BUILD_ROOT install-bfd install-opcodes
if [ ! -f "%buildroot/%_bindir/ld.bfd" ]; then
  mv "%buildroot/%_bindir"/{ld,ld.bfd};
else
  rm -f "%buildroot/%_bindir/ld";
fi
mkdir -p "%buildroot/%_sysconfdir/alternatives";
# Keep older versions of brp-symlink happy
%if %{suse_version} < 1310
ln -s "%_bindir/ld" "%buildroot/%_sysconfdir/alternatives/ld"
%endif
ln -s "%_sysconfdir/alternatives/ld" "%buildroot/%_bindir/ld";
rm -rf $RPM_BUILD_ROOT%{_prefix}/%{HOST}/bin
mkdir -p $RPM_BUILD_ROOT%{_prefix}/%{HOST}/bin
ln -sf ../../bin/{ar,as,ld,nm,ranlib,strip} $RPM_BUILD_ROOT%{_prefix}/%{HOST}/bin
mv $RPM_BUILD_ROOT%{_prefix}/%{HOST}/lib/ldscripts $RPM_BUILD_ROOT%{_libdir}
ln -sf ../../%{_lib}/ldscripts $RPM_BUILD_ROOT%{_prefix}/%{HOST}/lib/ldscripts
# Install header files
make -C libiberty install_to_libdir target_header_dir=/usr/include DESTDIR=$RPM_BUILD_ROOT
# We want the PIC libiberty.a
install -m 644 libiberty/pic/libiberty.a $RPM_BUILD_ROOT%{_libdir}
#
chmod a+x $RPM_BUILD_ROOT%{_libdir}/libbfd-*
chmod a+x $RPM_BUILD_ROOT%{_libdir}/libopcodes-*
# No shared linking outside binutils
rm $RPM_BUILD_ROOT%{_libdir}/lib{bfd,opcodes}.so
rm $RPM_BUILD_ROOT%{_libdir}/lib{bfd,opcodes}.la
# Remove unwanted files to shut up rpm
rm -f $RPM_BUILD_ROOT%{_infodir}/configure* $RPM_BUILD_ROOT%{_infodir}/standards.info*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/dlltool.1 $RPM_BUILD_ROOT%{_mandir}/man1/windres.1 $RPM_BUILD_ROOT%{_mandir}/man1/windmc.1
cd ..
%find_lang binutils
%find_lang bfd binutils.lang
%find_lang gas binutils.lang
%find_lang ld binutils.lang
%find_lang opcodes binutils.lang
%find_lang gprof binutils.lang
%ifarch %gold_archs
%find_lang gold binutils-gold.lang
%endif
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
install -m 644 binutils/NEWS $RPM_BUILD_ROOT%{_docdir}/%{name}/NEWS-binutils
install -m 644 gas/NEWS $RPM_BUILD_ROOT%{_docdir}/%{name}/NEWS-gas
install -m 644 ld/NEWS $RPM_BUILD_ROOT%{_docdir}/%{name}/NEWS-ld
%else
# installing cross-TARGET-binutils and TARGET-binutils
make DESTDIR=$RPM_BUILD_ROOT install
# Replace hard links by symlinks, so that rpmlint doesn't complain
T=$(basename %buildroot/usr/%{TARGET_OS})
for f in %buildroot/usr/$T/bin/* ; do
   ln -sf /usr/bin/$T-$(basename $f) $f
done
%if "%{TARGET}" == "avr"
install -c gas-nesc/as-new $RPM_BUILD_ROOT%{_prefix}/bin/%{TARGET_OS}-nesc-as
ln -sf ../../bin/%{TARGET_OS}-nesc-as $RPM_BUILD_ROOT%{_prefix}/%{TARGET_OS}/bin/nesc-as
%endif
rm -rf $RPM_BUILD_ROOT%{_mandir}
rm -rf $RPM_BUILD_ROOT%{_infodir}
rm -rf $RPM_BUILD_ROOT%{_prefix}/lib*
rm -rf $RPM_BUILD_ROOT%{_prefix}/include
rm -f $RPM_BUILD_ROOT%{_prefix}/bin/*-c++filt
> ../binutils.lang
%endif

%if 0%{!?cross:1}
%post
"%_sbindir/update-alternatives" --install \
	"%_bindir/ld" ld "%_bindir/ld.bfd" 2
%install_info --info-dir=%{_infodir} %{_infodir}/as.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/bfd.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/binutils.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/gprof.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/ld.info.gz

%post gold
"%_sbindir/update-alternatives" --install \
	"%_bindir/ld" ld "%_bindir/ld.gold" 1

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/as.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/bfd.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/binutils.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gprof.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/ld.info.gz
if [ "$1" = 0 ]; then
	"%_sbindir/update-alternatives" --remove ld "%_bindir/ld.bfd";
fi;

%preun gold
if [ "$1" = 0 ]; then
	"%_sbindir/update-alternatives" --remove ld "%_bindir/ld.gold";
fi;

%endif

%files -f binutils.lang
%defattr(-,root,root)
%if 0%{!?cross:1}
%{_docdir}/%{name}
%{_prefix}/%{HOST}/bin/*
%{_prefix}/%{HOST}/lib/ldscripts
%{_libdir}/ldscripts
%{_bindir}/*
%ghost %_sysconfdir/alternatives/ld
%ifarch %gold_archs
%exclude %{_bindir}/gold
%exclude %{_bindir}/ld.gold
%endif
%doc %{_infodir}/*.gz
%{_libdir}/lib*-%{version}*.so
%doc %{_mandir}/man1/*.1.gz
%else
%{_prefix}/%{TARGET_OS}
%{_prefix}/bin/*
%endif

%ifarch %gold_archs
%files gold -f binutils-gold.lang
%defattr(-,root,root)
%doc gold/NEWS gold/README
%{_bindir}/gold
%{_bindir}/ld.gold
%endif

%if 0%{!?cross:1}
%files devel
%defattr(-,root,root)
%{_prefix}/include/*.h
%{_libdir}/lib*.*a
%endif

%changelog
* Wed Jul  6 2016 rguenther@suse.com
- Update to binutils 2.26.1. [fate #320851]
- Remove binutils-2.26-branch.diff.
* Mon Jun 20 2016 matz@suse.com
- Update binutils-2.26-branch.diff to branch head.
- Adjust testcases from ld-dtags.diff (bnc#985642).
* Thu Mar 17 2016 rguenther@suse.com
- Update binutils-2.26-branch.diff, updates to branch head.
  (swo#19807) (bnc#970239)
- Disable -mrelax-relocations by default on old products.
* Wed Mar  9 2016 rguenther@suse.com
- Update binutils-2.26-branch.diff, updates to branch head.
  (swo#19739) (swo#19775)
* Mon Feb 29 2016 rguenther@suse.com
- Add binutils-2.26-branch.diff, updates to branch head.
  * Adds -mrelax-relocations on x86
  * Fixes bso#19698
* Mon Feb  1 2016 rguenther@suse.com
- Refresh cross-avr-nesc-as.patch
* Wed Jan 27 2016 rguenther@suse.com
- Update to binutils 2.26  [fate#319939]
  * Add --fix-stm32l4xx-629360 to the ARM linker to enable a link-time
    workaround for a bug in the bus matrix / memory controller for some of
    the STM32 Cortex-M4 based products (STM32L4xx)
  * Add a configure option --enable-compressed-debug-sections={all,ld} to
    decide whether DWARF debug sections should be compressed by default.
  * Add support for the ARC EM/HS, and ARC600/700 architectures.
  * Experimental support for linker garbage collection (--gc-sections)
    has been enabled for COFF and PE based targets.
  * New command line option for ELF targets to compress DWARF debug
    sections, --compress-debug-sections=[none|zlib|zlib-gnu|zlib-gabi].
  * New command line option, --orphan-handling=[place|warn|error|discard], to
    adjust how orphan sections are handled.  The default is 'place' which gives
    the current behaviour, 'warn' and 'error' issue a warning or error
    respectively when orphan sections are found, and 'discard' will discard all
    orphan sections.
  * Add support for LLVM plugin.
  * Add --print-memory-usage option to report memory blocks usage.
  * Add --require-defined option, it's like --undefined except the new symbol
    must be defined by the end of the link.
  * Add a configure option --enable-compressed-debug-sections={all,gas} to
    decide whether DWARF debug sections should be compressed by default.
  * Add support for the ARC EM/HS, and ARC600/700 architectures.  Remove
    assembler support for Argonaut RISC architectures.
  * Add option to objcopy to insert new symbols into a file:
  - -add-symbol <name>=[<section>:]<value>[,<flags>]
  * Add support for the ARC EM/HS, and ARC600/700 architectures.
  * Extend objcopy --compress-debug-sections option to support
  - -compress-debug-sections=[none|zlib|zlib-gnu|zlib-gabi] for ELF
    targets.
  * Add --update-section option to objcopy.
  * Add --output-separator option to strings.
- Includes z13 support, remove 0001-S-390-Add-support-for-IBM-z13.patch,
  0002-S-390-Add-check-for-length-field-operand.patch,
  0003-S-390-Add-more-IBM-z13-instructions.patch,
  0004-S-390-Fixes-for-z13-instructions.patch and
  0005-S-390-z13-use-GNU-attribute-to-indicate-vector-ABI.patch
- Includes fixes in binutils-fix--dynamic-list.patch,
  binutils-fix-gold-aarch64.diff, gold-arm64-abi-pagesize.patch
  and s390-troo-insn-type.patch
- Refresh s390-pic-dso.diff and binutils-build-as-needed.diff
* Wed Jan 13 2016 schwab@suse.de
- gold-relocate-tls.patch: Fix internal error when applying TLSDESC
  relocations with no TLS segment
* Wed Oct 14 2015 schwab@suse.de
- s390-troo-insn-type.patch: fix wrong insn type for troo insn
- aarch64-common-pagesize.patch: change default common-page-size to 64K on
  aarch64
* Thu Oct  1 2015 schwab@suse.de
- gold-arm64-abi-pagesize.patch: fix ABI pagesize for aarch64 in gold
  [bsc#949066]
* Thu Jul  9 2015 matz@suse.com
- Update SLE12 package for toolchain module
  and maintenance update.  [fate #318036, fate #318238,
  fate #318520, bnc #936050, bnc #926412]
- Removed SLE-only patches for hardening, obsoleted
  by update to 2.25: binutils-fuzz-fix.diff,
  binutils-new-readelf.tar.gz, binutils-readelf-header.diff .
* Thu Jul  9 2015 matz@suse.de
- Update to 2.25 branch at 2f5b97b4f (changes
  binutils-2.25-branch.diff.gz) fixes PR 18481, gas/18541.
- Add patches for s390 z13 support (backports from
  to-be 2.26):
  0001-S-390-Add-support-for-IBM-z13.patch
  0002-S-390-Add-check-for-length-field-operand.patch
  0003-S-390-Add-more-IBM-z13-instructions.patch
  0004-S-390-Fixes-for-z13-instructions.patch
  0005-S-390-z13-use-GNU-attribute-to-indicate-vector-ABI.patch .
* Tue Jul  7 2015 afaerber@suse.de
- Fix %%TARGET vs. $TARGET_OS inconsistencies by turning $TARGET_OS
  into %%TARGET_OS for reuse in install and file sections.
  This fixes the assumption that $TARGET_OS will match %%{TARGET}*.
* Wed Jun 10 2015 dmueller@suse.com
- enable gold for aarch64
* Mon May 18 2015 matz@suse.de
- Move sed call from %%prep to %%build to not disturb quilt.
- Add binutils-2.25-branch.diff.gz:
  Update to 2.25 branch at 8fe8994c, fixing many bugs:
  PR ld/15228, binutils/17512, 17165, binutils/17531, ld/17615, 17666,
  ld/17709, gas/17753, 17755, 17817, ld/17827, 17842, binutils/17926,
  17954, 18010, ld/18167, ld/18222, ld/18270.
- Remove eh-frame-hdr-on-shared-lib-bfd.patch: Included already.
- Remove gold-opd-visibility.patch: Included already.
* Mon May 18 2015 meissner@suse.com
- move info deinstall to preun section
* Sat May 16 2015 hrvoje.senjan@gmail.com
- Added binutils-fix--dynamic-list.patch:
  Fixes https://sourceware.org/bugzilla/show_bug.cgi?id=13577 and
  https://sourceware.org/bugzilla/show_bug.cgi?id=16992
* Thu Feb 19 2015 schwab@suse.de
- gold-opd-visibility.patch: Set default visibility on discarded .opd
  symbols
* Wed Jan 21 2015 schwab@suse.de
- eh-frame-hdr-on-shared-lib-bfd.patch: Don't create .eh_frame_hdr on
  shared lib bfd, fixes building libgcj on ppc64
* Thu Jan 15 2015 rguenther@suse.com
- Update to binutils 2.25 release.
  * Add --data option to strings to only print strings in loadable, initialized
    data sections.  Change the default behaviour to be --all, but add a new
    configure time option of --disable-default-strings-all to restore the old
    default behaviour.
  * Add --include-all-whitespace to strings.
  * Add --dump-section option to objcopy.
  * Add support for the Andes NDS32.
  * PE binaries now once again contain real timestamps by default.  To disable
    the inclusion of a timestamp in a PE binary, use the --no-insert-timestamp
    command line option.
  * Replace support for openrisc and or32 with support for or1k.
  * Add support for the --build-id command line option to COFF based targets.
  * x86/x86_64 pe-coff now supports the --build-id option.
  * Add support for the AVR Tiny microcontrollers.
  * Enhanced the ARM port to accept the assembler output from the CodeComposer
    Studio tool.  Support is enabled via the new command line option -mccs.
- Update to 2.25 branch head.
  * Pulls PIE fixes.
* Mon Jan 12 2015 dimstar@opensuse.org
- Minor fix on the usage of update-alternatives
  https://en.opensuse.org/openSUSE:Packaging_Multiple_Version_guidelines
* Mon Dec  1 2014 matz@suse.de
- Update to current 2.25 pre-release branch, at 127a4644.
- binutils-fix-gold-aarch64.diff: fixing build temporarily broken
  on brach.
- Remove obsolete patches: binutils-2.24-branch.diff.gz,
  pie-m68k.patch, binutils-2.24-auto-plugin.diff, ld-testsuite.patch,
  binutils-2.24-bso16746.diff .
* Mon Dec  1 2014 matz@suse.com
- Fix for several CVEs found when feeding fuzzed binary files into
  various binutils programs like strings, objdump or readelf.
  [bnc #902676, #902677, #903655, #905735, #905736]
  [CVE-2014-8485, CVE-2014-8484, CVE-2014-8501, CVE-2014-8502,
  CVE-2014-8503, CVE-2014-8504, CVE-2014-8738, CVE-2014-8737]
  [PR17510, PR17512, PR17521, PR17531, PR17533, PR17552, PR17597,
  PR17605]
* Fri Oct 31 2014 afaerber@suse.de
- Enable Adapteva Epiphany target
* Tue May  6 2014 rguenther@suse.com
- binutils-2.24-bso16746.diff: Fix bso#16746, spurious warnings
  for warn annotated symbols with LTO.
* Sun Apr  6 2014 schwab@linux-m68k.org
- ld-dtags.diff: update testsuite for --enable-new-dtags default
- ld-testsuite.patch: fix spurious failures in ld-plugin/lto.exp
* Thu Apr  3 2014 rguenther@suse.com
- binutils-2.24-auto-plugin.diff: Update from git commit that went
  to trunk.
* Wed Mar 26 2014 matz@suse.de
- Update to current 2.24 branch at 25f1c421:
  AVX512 fixes, new x86 instructions clflushopt, xsaves, xsavec, xrstors.
  aarch64: linker fixes for PLT stubs, correct float const 0.0 parsing,
  support ifunc in static links.
  Fix ld/16643 (problem with GCed sections).
  powerpc64le: fix ld segfault with --emit-relocs.
  Fix buffer underrun in x86 disassembler.
  Fix merging of skipped weak symbols.  [bnc #863764]
* Mon Mar 24 2014 rguenther@suse.com
- Add binutils-2.24-auto-plugin.diff to make plugin auto-load work
  for GCC LTO objects.  [bso#14698]
* Fri Feb 21 2014 matz@suse.de
- Disable --enable-deterministic-archives again, as it breaks
  valid Makefiles.
* Mon Feb 10 2014 subchaser1@gmail.com
- cross-avr-size.patch: AVR-style output in avr-size utility
* Mon Jan 27 2014 crrodriguez@opensuse.org
- build with --enable-deterministic-archives so ar and ranlib
  cooperate in the creation of reproducible builds.
* Mon Dec  9 2013 matz@suse.de
- Update to 2.24 release and to branch at 9177510e:
  * Add support for the Texas Instruments MSP430X processor.
  * Add support for Altera Nios II.
  * Add support for the V850E3V5 architecture.
  * Add support for the Imagination Technologies Meta processor.
  * --enable-new-dtags no longer generates old dtags in addition to new dtags.
  * Remove assembler and linker support for MIPS ECOFF targets.
  * Remove assembler support for MIPS ECOFF targets.
  * Add ALIGN_WITH_INPUT to the linker script language to force the
    alignment of an output section to use the maximum alignment of
    all its input sections.
  * Add -gdwarf-sections command line option to enable per-code-section
    generation of DWARF .debug_line sections.
  * Objcopy now supports wildcard characters in command line options that take
    section names.
* Fri Nov 29 2013 matz@suse.de
- Update to 2.23.92 prerelease, mostly for ppc64le support.
- Add cross-ppc64le-binutils.
* Mon Oct 28 2013 schwab@suse.de
- Add cross-m68k-binutils
* Wed Oct  9 2013 schwab@suse.de
- pie-m68k.patch: Emit DT_DEBUG also for PIE
* Fri Sep 20 2013 matz@suse.de
- Update to 2.23.90 prerelease, remove patches that
  are upstream ( aarch64-biarch.patch, aarch64-dynamic-placement.patch,
  aarch64-execstack.patch, aarch64-gc-section-support.patch,
  aarch64-support-1796bf893c4729d5c523502318d72cae78495d6c.diff,
  aarch64-support-f426901e1be0f58fe4e9386cada50ca57d0a4f36.diff,
  binutils-2.22-objalloc.patch,
  binutils-2.23.52.0.1-64-bit-thin-archives.patch,
  s390-machinemode.patch, warning-symbol-sections.patch).
* Sat Aug 31 2013 idonmez@suse.com
- Add binutils-2.23.52.0.1-64-bit-thin-archives.patch to fix thin
  archive creation on 64bit systems. This is rh#915411 and should
  also fix webkitgtk on s390x.
* Mon Jul 29 2013 schwab@suse.de
- warning-symbol-sections.patch: correct test in last change
* Mon Jul 22 2013 schwab@suse.de
- warning-symbol-sections.patch: don't clobber warning sections from
  shared libraries
* Mon Jul  1 2013 schwab@suse.de
- aarch64-dynamic-placement.patch: Correct placement of &_DYNAMIC
* Wed Jun 26 2013 dmueller@suse.com
- add armv6l to target list
* Tue Jun 11 2013 dmueller@suse.com
- add aarch64-support-1796bf893c4729d5c523502318d72cae78495d6c.diff
- add aarch64-support-f426901e1be0f58fe4e9386cada50ca57d0a4f36.diff
* Wed May 15 2013 rguenther@suse.com
- Drop cross-alpha-binutils.  Adjust pre-checkin.sh to remove
  all cross packages before re-generating them.
* Tue May 14 2013 schwab@suse.de
- Tell bfd ELF backend that aarch64 defaults to non-exec stack
* Wed Apr  3 2013 rguenther@suse.com
- Re-instantiate patch to warn about non-PIC code in shared objects
  on s390x.
* Thu Mar 28 2013 rguenther@suse.com
- Update to binutils 2.23.2.
  * various bugfixes
- Refresh no longer applying patch.
* Tue Mar  5 2013 schwab@suse.de
- Add aarch64 support for --gc-sections
  (from http://sourceware.org/ml/binutils/2013-02/msg00285.html)
* Wed Dec 19 2012 schwab@suse.de
- Backport s390 .machinemode pseudo insn
* Fri Nov 30 2012 rguenther@suse.com
- Revert upstream change to error on bfd.h usage without first
  including some config.h
* Wed Nov 28 2012 rguenther@suse.com
- Change update-alternative priorities to always prefer GNU ld
* Tue Nov 27 2012 jengelh@inai.de
- Implement update-alternatives service for gold
* Tue Nov 27 2012 adrian@suse.de
- update to version 2.23.1 release
- add aarch64 biarch patch
* Sat Nov 24 2012 adrian@suse.de
- add cross-aarch64-binutils
* Thu Nov 22 2012 jengelh@inai.de
- Have pre_checkin.sh create cross-sparc64-binutils
* Wed Oct 24 2012 rguenther@suse.com
- Update to binutils 2.23 branch head.
  * Includes binutils 2.23 release.
* Mon Sep 17 2012 rguenther@suse.com
- Update to binutils 2.23 release candidate.
- Remove no longer applying AVR patch.
* Fri Sep  7 2012 coolo@suse.com
- add makeinfo as explicit buildrequire
* Mon Sep  3 2012 idonmez@suse.com
- Enable threaded linking in gold.
* Mon Sep  3 2012 rguenther@suse.com
- Add patch to fix libiberty integer overflow.  [bnc#776968]
* Thu Jun 21 2012 adrian@suse.de
- fix default elf format for arm cross tools
* Tue Jun 19 2012 factory-maintainer@kulow.org
- fix stupid typo
* Mon Jun 18 2012 coolo@suse.com
- the previous fix was not good enough, another iteration of the same
* Thu Jun 14 2012 coolo@suse.com
- exclude our target arch for cross compiling - this is just not cross
* Thu Apr 19 2012 rguenther@suse.com
- Consistently use $target-suse-linux triplets.
* Wed Feb 15 2012 rguenther@suse.com
- Drop the new spec files again, instead move the cross-$arch-binutils
  contents to /usr, away from /opt.
* Tue Feb 14 2012 max@suse.com
- Add spec files that build variants for arm and avr that install
  under /usr rather than /opt/cross.
- Add avr-binutils-relocs.patch to fix a crash in avr-ld.
  http://sourceware.org/bugzilla/show_bug.cgi?id=12161
* Thu Jan 26 2012 rguenther@suse.com
- Fix package licenses to follow SPDX format, adjust to reality.
* Wed Jan 25 2012 rguenther@suse.com
- Amend patch to fix arm unwind table corruption.  [bso#13449]
* Wed Jan  4 2012 rguenther@suse.com
- Add patch to fix arm unwind table corruption.  [bso#13449]
- Canonicalize arm targets.
- Enable gold for arm.
* Tue Jan  3 2012 rguenther@suse.com
- Add patch to fix build-id issues.  [bso#12451]
* Tue Dec  6 2011 rguenther@suse.com
- Update to final binutils 2.22 release.
* Wed Nov  2 2011 rguenther@suse.com
- Update to binutils-2_22-branch head.
  * Adds support for LDPT_GET_SYMBOLS_V2.
  * Drop patches that have been applied upstream.
* Fri Sep 30 2011 tserong@suse.com
- Fix --gc-sections failure with symbol versioning [bso#13195]
* Wed Sep 28 2011 rguenther@suse.com
- Update to binutils-2_22-branch head.
  * Drop patches that have been applied upstream.
  * Drop patches that no longer apply.
* Thu Sep 22 2011 adrian@suse.de
- use -gnueabi extension to switch to new abi for arm
* Thu Sep 22 2011 dmueller@suse.de
- Add support for arm-*-gnueabihf targets (PR ld/12643)
* Wed Sep 21 2011 adrian@suse.de
- add arm targets
* Tue Aug 23 2011 rguenther@novell.com
- Fix XLC object linker complaints.  [bnc#713504]
* Sun Aug 21 2011 aj@suse.de
- Make --no-copy-dt-needed-entries the default for ld.
* Tue Jul 12 2011 rguenther@novell.com
- Add patch for bogus executable stack setting with -flto.  [bso#12982]
* Mon Jul 11 2011 rguenther@novell.com
- BuildRequire glibc-devel-static to fix static linking tests.
* Tue Jul  5 2011 saschpe@suse.de
- Add patch to fix a readelf endless loop bug.  [bso#12855]
* Tue Jun 28 2011 rguenther@novell.com
- Update to binutils 2.21.1 release.
  * Add --interleave-width option to objcopy to allowing copying a range
    of bytes from the input to the output with the --interleave option.
  * Add support for the TMS320C6000 (TI C6X) processor family.
  * Readelf can now display ARM unwind tables (.ARM.exidx / .ARM.extab)
    using the -u / --unwind option.
  * Add --dyn-syms to readelf to dump dynamic symbol table.
  * A new tool - elfedit - has been added to directly manipulate ELF
    format binaries.
  * Add to dlltool .def file feature of aliasing PE internal symbol name
    by '== <ID>' option.
  * Add a new command line option -a / --addresses to addr2line to display
    the address before function name or source filename.
  * Add a new command line option -p / --pretty-print to addr2line to have
    a more human readable output.
  * The hppa/som targets can now be compiled on any host.
- Add dependency to opcodes from gold.
* Fri Jun 17 2011 matz@suse.de
- Add support for x86_64-pep target [needed for Xen fate #311376]
* Thu Jun  9 2011 matz@novell.com
- Add patch to support AMD Bulldozer v2 [fate #312149]
* Tue Jun  7 2011 rguenther@novell.com
- Update to binutils-2_21-branch head.  [bnc#698346]
* Fri May 27 2011 rguenther@novell.com
- Disable cross-sh4-binutils.
* Wed May  4 2011 rguenther@novell.com
- Update to binutils-2_21-branch head.  [bnc#691290]
* Tue Apr 19 2011 rguenther@novell.com
- Update to binutils-2_21-branch head.  [fate#311554] [fate#311972]
* Mon Jan 10 2011 rguenther@novell.com
- Update to binutils 2.21.
  * linker plugin support
  * AMD Bulldozer enablement
- Disable package fail when testsuite failures occur for now
  because of gold (testsuite) issues.
* Tue Jul 27 2010 rguenther@novell.com
- drop cross-avr-binutils
* Tue Jul 27 2010 coolo@novell.com
- split the gold build into 2 make steps to avoid random
  build failures (ugly work around in fact)
* Thu Jul  8 2010 jengelh@medozas.de
- Default to creating ELF64 objects under sparc64
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Mon Apr 12 2010 matz@suse.de
- Initialize memory for MALLOC_PERTURB on ppc.  [PR gas/11486]
  Rewrite history by including this:
    Wed Mar 24 17:23:32 CET 2010 - matz@suse.de
  - Fix testcase breaking with MALLOC_PERTURB.  [bnc #590820]
    Sat Feb 13 17:52:11 CET 2010 - rguenther@suse.de
  - Drop build counter from the libbfd and libopcode SONAMEs.
    Fri Jan 22 15:31:06 CET 2010 - matz@suse.de
  - Update to current binutils-2_20-branch.  [bnc #561142, #573019]
    Wed Jan 13 15:16:44 CET 2010 - matz@novell.com
  - Fix removal of unwanted files (man,info,libiberty) on the
    cross binutils.
    Sat Dec 12 19:09:40 CET 2009 - jengelh@medozas.de
  - add baselibs.conf as a source
    Mon Dec  7 16:14:27 CET 2009 - jengelh@medozas.de
  - SPARC build support for binutils
    Wed Nov  4 15:44:30 CET 2009 - matz@suse.de
  - Copy from SLE11 SP1.  Compared to that add --as-needed by default
    patch again.
    Mon Oct 19 11:15:51 CEST 2009 - rguenther@suse.de
  - Update to binutils 2.20 snapshot.
  * disable patches that no longer apply
  * disable make check handling everywhere
* Fri Apr  9 2010 matz@suse.de
- Fix encoding of LWP instructions, and get rid of 16bit forms.
* Fri Feb 12 2010 matz@suse.de
- Add more aliases for VPCOM* instructions, xsave64, xrstor64,
  and vpermil2p (XOP support).
* Tue Feb  9 2010 matz@suse.de
- Add support for AMD XOP instructions.  [bnc #578249]
* Fri Jan 22 2010 matz@suse.de
- Update to current binutils-2_20-branch.  [bnc #561142, #573019]
* Wed Nov  4 2009 matz@suse.de
- Update to binutils 2.20 branch, remove patches that went upstream.
  Don't activate --as-needed by default for SLE11 SP1.
  [fate #306880, #307034]
  [bnc #546106, #483978]
* Mon Oct 12 2009 rguenther@suse.de
- enable gold plugins, fix build on older distros.
* Wed Oct  7 2009 coolo@novell.com
- obsolete binutils-32bit, it can't be left around
* Mon Aug 24 2009 rguenther@suse.de
- disable gold build before openSUSE 11.0.
* Thu Aug 20 2009 rguenther@suse.de
- add patch to drop .gnu.lto_* sections
* Fri Jun 12 2009 coolo@novell.com
- follow only SUSE_ASNEEDED
* Tue Jun  9 2009 matz@suse.de
- Use --as-needed by default in the build system.
* Wed May 27 2009 rguenther@suse.de
- Update to head of trunk.
- Add patch to fix gold build with glibc 2.10, gcc 4.4.
* Fri Mar 27 2009 rguenther@suse.de
- Update to head of trunk.
- Add zlib-devel-static BuildRequires to fix testsuite.
- Package gold locales.
* Mon Feb 16 2009 schwab@suse.de
- Update to head of trunk.
* Mon Feb 16 2009 rguenther@suse.de
- Update to 2.19.51 snapshot.  Fixes build with GCC 4.4.
* Tue Jan 27 2009 schwab@suse.de
- Update to head of trunk.
* Thu Jan 22 2009 schwab@suse.de
- Adjust list of extra targets.
* Mon Jan 19 2009 schwab@suse.de
- Update to head of trunk.
- Add gold.
* Thu Jan 15 2009 schwab@suse.de
- Use consistent label names.
* Thu Jan 15 2009 olh@suse.de
- remove Requires: binutils-XXbit in binutils-devel-XXbit package
* Fri Jan  9 2009 schwab@suse.de
- Fix last change.
* Fri Jan  9 2009 olh@suse.de
- build binutils and binutils-devel -XXbit packages (bnc#445037)
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Dec  4 2008 schwab@suse.de
- Update symbol visibility checks during linking on s390.
* Wed Dec  3 2008 schwab@suse.de
- Fix corner case during link relaxing.
* Thu Nov 27 2008 schwab@suse.de
- Fix disassembler bug.
- Help some devel users.
* Fri Nov 21 2008 schwab@suse.de
- Import bugfixes from 2.19 branch.
* Wed Nov 19 2008 schwab@suse.de
- Fix handling of DW_CFA_advance_loc* in the assembler.
* Mon Nov 10 2008 schwab@suse.de
- Update last change.
* Fri Nov  7 2008 schwab@suse.de
- Fix crash in strip.
* Thu Nov  6 2008 rguenther@suse.de
- build cross-spu-binutils with a /usr/spu sysroot
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Oct 20 2008 schwab@suse.de
- Update to binutils 2.19.
  * Added -wL switch to dump decoded contents of .debug_line.
  * Added support for "thin" archives which contain pathnames pointing to
    object files rather than the files themselves and which contain a
    flattened symbol index for all objects, and archives, which have been
    added to the archive.
  * Added -F switch to objdump to include file offsets in the disassembly.
  * Added -c switch to readelf to allow string dumps of archive symbol index.
  * Support for SSE5 has been added to the i386 port.
  * Added -p switch to readelf to allow string dumps of sections.
  * New pseudo op .cfi_val_encoded_addr, to record constant addresses in unwind
    tables without runtime relocation.
  * New command line option, -h-tick-hex, for sh, m32c, and h8/300 targets, which
    adds compatibility with H'00 style hex constants.
  * New command line option, -msse-check=[none|error|warning], for x86
    targets.
  * New sub-option added to the assembler's -a command line switch to
    generate a listing output.  The 'g' sub-option will insert into the listing
    various information about the assembly, such as assembler version, the
    command line options used, and a time stamp.
  * New command line option -msse2avx for x86 target to encode SSE
    instructions with VEX prefix.
  * Add Intel XSAVE, EPT, MOVBE, AES, PCLMUL, AVX/FMA support for x86 target.
  * New command line options, -march=CPU[,+EXTENSION...], -mtune=CPU,
  - mmnemonic=[att|intel], -msyntax=[att|intel], -mindex-reg,
  - mnaked-reg and -mold-gcc, for x86 targets.
  * Support for generating wide character strings has been added via the new
    pseudo ops: .string16, .string32 and .string64.
  * Support for SSE5 has been added to the i386 port.
  * Linker scripts support a new INSERT command that makes it easier to
    augment the default script.
  * Linker script input section filespecs may now specify a file within an
    archive by writing "archive:file".
  * The --sort-common switch now has an optional argument which specifies the
    direction of sorting.
  * The M68K linker now supports multiple GOT generation schemes controlled via
    the --got=<type> command line option.
  * The ARM EABI linker will now generate stubs for function calls to symbols
    that are too far away.  The placement of the stubs is controlled by a new
    linker command line option: --stub-group-size=N.
* Thu Oct  9 2008 schwab@suse.de
- Bug fixes.
* Tue Oct  7 2008 jblunck@suse.de
- bfd-assign_file_positions_for_load_sections-STRIP_NONDEBUG-fix.diff:
  Do not only look at the first section in a segment to decide if it has
  contents or not. This fixes the "section ... can't be allocated in segment"
  errors when using objcopy --only-keep-debug to create the *.debug files.
* Wed Sep 17 2008 schwab@suse.de
- Update to binutils 2.18.91 snapshot.
* Fri Sep 12 2008 schwab@suse.de
- Update to head of 2.19 branch.
* Thu Sep  4 2008 schwab@suse.de
- Update to head of trunk.
* Fri Aug  8 2008 schwab@suse.de
- Update to head of trunk.
* Fri Jul 18 2008 schwab@suse.de
- Update to head of trunk.
* Sun Jul 13 2008 olh@suse.de
- enable targets i386-macos10, powerpc-macos, powerpc-macos10,
  spu-elf unconditionally in binutils
* Fri Jul 11 2008 schwab@suse.de
- Update to head of trunk.
* Wed Jun 18 2008 schwab@suse.de
- Update to head of trunk.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 schwab@suse.de
- Update to head of trunk.
* Tue Mar 25 2008 schwab@suse.de
- Update to head of trunk.
* Fri Mar  7 2008 schwab@suse.de
- Update to head of trunk.
* Mon Feb 25 2008 schwab@suse.de
- Update to head of trunk.
* Fri Feb 15 2008 schwab@suse.de
- Update to head of trunk.
* Sun Feb 10 2008 schwab@suse.de
- Allow R_S390_PC32DBL against protected function symbols.
* Fri Feb  1 2008 schwab@suse.de
- Update to head of trunk.
* Fri Jan 25 2008 schwab@suse.de
- Update to head of trunk.
* Thu Jan 17 2008 schwab@suse.de
- Update to head of trunk.
* Thu Jan 10 2008 schwab@suse.de
- Update to head of trunk.
* Mon Nov 12 2007 schwab@suse.de
- Update to head of trunk.
* Tue Oct  2 2007 schwab@suse.de
- Update to head of trunk.
- Add hppa64 target.
* Mon Sep  3 2007 schwab@suse.de
- Add fix for PR4888.
* Thu Jul 26 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jul 13 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jun 29 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jun 22 2007 schwab@suse.de
- Update to head of trunk.
- Drop Bdirect patches.
* Mon Jun 11 2007 schwab@suse.de
- Update to head of trunk.
* Sat Jun  2 2007 schwab@suse.de
- Allow only static linking of lib{bfd,opcodes} outside binutils.
* Tue May 15 2007 schwab@suse.de
- Update to head of trunk.
* Fri May  4 2007 schwab@suse.de
- Update to binutils CVS HEAD.
- Remove obsolete obsoletes.
* Mon Apr 23 2007 olh@suse.de
- Fix POWER6 floating point disassembling [#266874]
* Thu Apr 12 2007 schwab@suse.de
- Build cross tools with sysroot.
* Thu Apr  5 2007 schwab@suse.de
- Update to binutils CVS HEAD.
- Add spu to the list of cross targets.
* Mon Mar 26 2007 rguenther@suse.de
- Add bison and flex BuildRequires.
* Wed Mar 21 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Fri Mar 16 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Sun Feb 25 2007 schwab@suse.de
- Add mips to the list of extra targets.
* Tue Feb 20 2007 schwab@suse.de
- Avoid build failure with interface change.
* Mon Feb 19 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Tue Feb  6 2007 rguenther@suse.de
- Add sh4 to the list of cross targets.
* Fri Feb  2 2007 schwab@suse.de
- Switch to hashtype=both by default.
* Mon Jan 29 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Wed Jan 24 2007 jw@suse.de
- fixed memory corruption in ld -m avr2 --oformat ihex a
  sourceware bugzilla#3874
* Tue Jan 23 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Mon Jan 15 2007 jw@suse.de
- bin/avr-nesc-as symlinked as avr/bin/nesc-as
* Fri Jan 12 2007 jw@suse.de
- Added avr-nesc-as support (rschiele@gmail.com)
* Mon Jan  8 2007 schwab@suse.de
- Update to binutils 2.17.50.0.9.
  1. Update from binutils 2007 0103.
  2. Fix --wrap linker bug.
  3. Improve handling ELF binaries generated by foreign ELF linkers.
  4. Various ELF M68K bug fixes.
  5. Score bug fixes.
  6. Don't read past end of archive elements. PR 3704.
  7. Improve .eh_frame_hdr section handling.
  8. Fix symbol visibility with comdat/linkonce sections in ELF linker.
  PR 3666.
  9. Fix 4 operand instruction handling in x86 assembler.
  10. Properly check the 4th operand in x86 assembler. PR 3712.
  11. Fix .cfi_endproc handling in assembler. PR 3607.
  12. Various ARM bug fixes.
  13. Various PE linker fixes.
  14. Improve x86 dissassembler for cmpxchg8b.
- Split off binutils-devel.
* Mon Dec  4 2006 schwab@suse.de
- Update to binutils 2.17.50.0.8.
  1. Update from binutils 2006 1201.
  2. Fix "objcopy --only-keep-debug" crash. PR 3609.
  3. Fix various ARM ELF bugs.
  4. Fix various xtensa bugs.
  5. Update x86 disassembler.
* Mon Oct 16 2006 schwab@suse.de
- Fix overflow in addend_compare [#209807].
* Fri Oct 13 2006 schwab@suse.de
- Update last change.
* Tue Oct 10 2006 schwab@suse.de
- Fix invalid debug info.
* Fri Oct  6 2006 aj@suse.de
- Improve last patch.
* Fri Oct  6 2006 aj@suse.de
- Fix PR210331 (wrong size of empty loadable sections).
* Thu Sep 28 2006 schwab@suse.de
- Update to binutils 2.17.50.0.5.
  1. Update from binutils 2006 0927.
  2. Fix linker regressions of section address and section relative symbol
  with empty output section. PR 3223/3267.
  3. Fix "strings -T". PR 3257.
  4. Fix "objcopy --only-keep-debug". PR 3262.
  5. Add Intell iwmmxt2 support.
  6. Fix an x86 disassembler bug. PR 3100.
* Wed Sep 27 2006 schwab@suse.de
- Fix uninitialized memory.
* Mon Sep 25 2006 schwab@suse.de
- Update to binutils 2.17.50.0.4.
  1. Update from binutils 2006 0924.
  2. Speed up linker on .o files with debug info on linkonce sections.
  PR 3111.
  3. Added x86-64 PE support.
  4. Fix objcopy/strip on .o files with section groups. PR 3181.
  5. Fix "ld --hash-style=gnu" crash with gcc 3.4.6. PR 3197.
  6. Fix "strip --strip-debug" on .o files generated with
  "gcc -feliminate-dwarf2-dups". PR 3186.
  7. Fix "ld -r" on .o files generated with "gcc -feliminate-dwarf2-dups".
  PR 3249.
  8. Add --dynamic-list to linker to make global symbols dynamic.
  9. Fix magic number for EFI ia64. PR 3171.
  10. Remove PT_NULL segment for "ld -z relro". PR 3015.
  11. Make objcopy to perserve the file formats in archive elements.
  PR 3110.
  12. Optimize x86-64 assembler and fix disassembler for
  "add32 mov xx,$eax". PR 3235.
  13. Improve linker diagnostics. PR 3107.
  14. Fix "ld --sort-section name". PR 3009.
  15. Updated an x86 disassembler bug. PR 3000.
  16. Various updates for PPC, ARM, MIPS, SH, Xtensa.
  17. Added Score support.
* Thu Sep 21 2006 schwab@suse.de
- Add support for --dynamic-list.
* Wed Aug  9 2006 schwab@suse.de
- Enable -zrelro by default.
* Wed Jul 26 2006 schwab@suse.de
- Fix bad gp value [#190362].
* Mon Jul 17 2006 schwab@suse.de
- Update to binutils 2.17.50.0.3.
  1. Update from binutils 2006 0715.
  2. Add --hash-style to ELF linker with DT_GNU_HASH and SHT_GNU_HASH.
  3. Fix a visibility bug in ELF linker (PR 2884).
  4. Properly fix the i386 TLS linker bug (PR 2513).
  5. Add assembler and dissassembler support for Pentium Pro nops.
  6. Optimize x86 nops for Pentium Pro and above.
  7. Add -march=/-mtune= to x86 assembler.
  8. Fix an ELF linker with TLS common symbols.
  9. Improve program header allocation in ELF linker.
  10. Improve MIPS, M68K and ARM support.
  11. Fix an ELF linker crash when reporting alignment change (PR 2735).
  12. Remove unused ELF section symbols (PR 2723).
  13. Add --localize-hidden to objcopy.
  14. Add AMD SSE4a and ABM new instruction support.
  15. Properly handle illegal x86 instructions in group 11 (PR 2829).
  16. Add "-z max-page-size=" and "-z common-page-size=" to ELF linker.
  17. Fix objcopy for .tbss sections.
* Tue Jun 13 2006 schwab@suse.de
- Handle hash resizing during as-needed processing.
* Fri Jun  9 2006 schwab@suse.de
- Disable hash resizing.
* Sat Jun  3 2006 schwab@suse.de
- Fix DT_NEEDED search with --as-needed libraries.
- Fix bfd_hash_lookup.
* Fri May 26 2006 schwab@suse.de
- Update to binutils 2.17.50.0.2.
* Mon May 15 2006 schwab@suse.de
- Update to binutils 2.17.50.0.1.
* Mon May  8 2006 hare@suse.de
- Fix invalid exeception on S/390 when calling res_init()
  [#172700 - LTC23600]
* Fri May  5 2006 schwab@suse.de
- Fix huge link times [#167593].
* Tue Apr 11 2006 schwab@suse.de
- PR ld/2442: fix quadratic behaviour with many relocations [#157119].
- PR ld/2513: fix invalid TLS reloc merging [#162901].
* Mon Apr  3 2006 schwab@suse.de
- Add various bug fix backports collected by Alan Modra.  Fixes the
  following binutils bugs:
  * PR ld/2443
  * PR ld/2462
  * PR ld/2267
  * incompatibilities between REL{32,24,14}
  * ld -r on ppc64
  * -msecure-plt vs TLS
* Fri Mar 31 2006 schwab@suse.de
- Fix build race.
* Fri Mar 31 2006 matz@suse.de
- Also disallow linking non-PIC .o files into shared libraries on
  s390x.
* Fri Mar 31 2006 schwab@suse.de
- Fix bfd_find_nearest_line so that gcc -frepo works again.
* Wed Feb 15 2006 matz@suse.de
- Update -Bdirect and -zdynsort patches.
* Mon Feb  6 2006 matz@suse.de
- Adjust testsuite for s390 -march=z900 default.
- Disallow linking non-PIC .o files into shared libraries on s390.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 matz@suse.de
- Add large model patch.
* Tue Jan 17 2006 schwab@suse.de
- Add patch to fix --gc-sections on ppc64.
- Fix side effect of --enable-targets=arm.
* Wed Jan 11 2006 schwab@suse.de
- Update to binutils 2.16.91.0.5.
* Tue Jan 10 2006 rguenther@suse.de
- Don't error out for testsuite failures on hppa.
* Tue Jan  3 2006 dmueller@suse.de
- Don't create empty rpath components when stripping
* Wed Dec  7 2005 schwab@suse.de
- Fix handling of SHF_LINK_ORDER links for objcopy.
* Wed Dec  7 2005 coolo@suse.de
- New -Bdirect patch.
* Fri Dec  2 2005 schwab@suse.de
- Add experimental -Bdirect patch.
* Thu Nov 24 2005 schwab@suse.de
- Fix aliasing warning.
* Sun Nov 13 2005 schwab@suse.de
- Update to binutils 2.16.91.0.4.
* Wed Nov  9 2005 schwab@suse.de
- Fixes from CVS:
  * Don't strip local absolute symbols from linker output.
  * Allow equating local symbols to undefined symbols.
* Fri Nov  4 2005 schwab@suse.de
- Fix more warnings.
* Wed Nov  2 2005 schwab@suse.de
- Fix warnings.
* Thu Oct 27 2005 aj@suse.de
- Spell fix.
* Wed Sep 28 2005 schwab@suse.de
- Add target i386-pe on ix86 and x86_64.
* Fri Sep 16 2005 schwab@suse.de
- Update to binutils 2.16.91.0.3.
* Thu Sep  1 2005 schwab@suse.de
- Fix objdump -adjust-vma on non-relocatable object [#114666].
* Wed Aug 10 2005 schwab@suse.de
- Replace last change by a simpler fix.
* Sat Aug  6 2005 schwab@suse.de
- Add hook for resetting GP after each relaxing pass.
* Fri Aug  5 2005 matz@suse.de
- Fix alpha again.
* Wed Aug  3 2005 schwab@suse.de
- Don't warn on overflow in the assembler if emitting a reloc on ppc
  [#100189].
- Fix handling of discarded linkonce sections [#84608].
* Tue Aug  2 2005 schwab@suse.de
- Avoid generating R_IA64_NONE.
* Tue Aug  2 2005 uli@suse.de
- disabled make check on ARM (one test fills up the hard disk;
  not a QEMU problem, happens on real hardware, too)
* Mon Jul 25 2005 schwab@suse.de
- Fix syntax error in libtool library files [#98185].
* Thu Jul 21 2005 schwab@suse.de
- Update to binutils 2.16.91.0.2.
* Thu Jun 23 2005 schwab@suse.de
- Update to binutils 2.16.91.0.1.
* Wed Jun 22 2005 schwab@suse.de
- Add patch to properly handle indirect symbols.
* Fri May 20 2005 schwab@suse.de
- Fix ld testsuite.
* Tue May 17 2005 schwab@suse.de
- Fix overflows in BFD library [#81821].
* Wed May 11 2005 schwab@suse.de
- Update to binutils 2.16.90.0.3.
- Build with -Wno-error in beta.
* Sat May  7 2005 schwab@suse.de
- Add patch to properly put unwind sections into section groups.
- Fix avr assembler.
* Sat May  7 2005 matz@suse.de
- added alpha cross target.
* Tue May  3 2005 jw@suse.de
- added target avr.
* Sun May  1 2005 schwab@suse.de
- Update to binutils 2.16.90.0.2.
* Thu Apr 28 2005 schwab@suse.de
- Update patch for last change.
* Mon Apr 25 2005 matz@suse.de
- Fix breakage on alpha
* Wed Apr 20 2005 bg@suse.de
- remove additional target hppa64
- remove obsolete hppa patch
- enable tests
* Sun Apr 17 2005 schwab@suse.de
- Accept empty symbol names.
- Fix bugs related to section groups.
* Wed Apr 13 2005 schwab@suse.de
- Fix mips assembler.
* Mon Apr 11 2005 schwab@suse.de
- Add patch to fix AS_NEEDED.
* Sun Apr 10 2005 schwab@suse.de
- Update to binutils 2.16.90.0.1.
* Wed Apr  6 2005 schwab@suse.de
- Cleanup neededforbuild.
- Fix compilation with gcc4.
* Wed Apr  6 2005 meissner@suse.de
- Added gettext-devel to neededforbuild.
* Tue Apr  5 2005 schwab@suse.de
- Revert last change (don't disable parallel build).
* Tue Apr  5 2005 meissner@suse.de
- Added gettext-devel to neededforbuild.
* Wed Mar 30 2005 schwab@suse.de
- Support AS_NEEDED in linker script.
* Fri Feb 18 2005 schwab@suse.de
- Update to binutils 2.15.94.0.2.2.
* Thu Feb  3 2005 schwab@suse.de
- Fix ld testsuite for gcc4.
* Sun Jan 30 2005 schwab@suse.de
- Add patch to properly handle protected functions for ia32 and x86_64.
* Thu Jan 20 2005 schwab@suse.de
- Fix last change.
* Wed Jan 19 2005 schwab@suse.de
- Handle biarch targets also for cross binutils.
* Sat Jan  8 2005 schwab@suse.de
- Update to binutils 2.15.94.0.2.
- Enable more targets.
* Tue Nov 23 2004 schwab@suse.de
- Update to binutils 2.15.94.0.1.
* Thu Oct 14 2004 schwab@suse.de
- Remove broken check.
* Wed Oct 13 2004 schwab@suse.de
- Fix ppc asm operand parsing.
* Fri Oct  8 2004 schwab@suse.de
- Update to binutils 2.15.92.0.2.
* Thu Sep  9 2004 schwab@suse.de
- Fix last change.
* Thu Sep  2 2004 schwab@suse.de
- Fix relro alignment.
* Sat Aug 21 2004 coolo@suse.de
- also build cross binutils for ppc64
* Fri Aug  6 2004 schwab@suse.de
- Fix crash in ld [#43550].
* Wed Aug  4 2004 schwab@suse.de
- Add patch for PR binutils/290.
* Sun Aug  1 2004 schwab@suse.de
- Make error about relocs against discarded sections non-fatal for now.
* Wed Jul 28 2004 schwab@suse.de
- Update to binutils 2.15.91.0.2.
* Fri Jun  4 2004 schwab@suse.de
- Update to binutils 2.15.91.0.1.
* Tue May  4 2004 coolo@suse.de
- created cross-*-binutils in the same directory reusing create-cross.sh
  as pre_checkin.sh
* Fri Apr 16 2004 aj@suse.de
- Fix some offset expressions.
* Thu Apr 15 2004 aj@suse.de
- Update to binutils 2.15.90.0.3.
* Wed Apr 14 2004 aj@suse.de
- Update to binutils 2.15.90.0.2.
* Fri Mar 26 2004 meissner@suse.de
- Added ppc64 patch to drop excess symbols in shared libraries.
* Tue Mar 23 2004 schwab@suse.de
- Fix --wrap on PPC64 [#34903].
* Tue Mar 16 2004 mludvig@suse.cz
- Added support for VIA PadLock.
- Merged obsolete fix-clflush.patch into opcode-i386.diff
* Fri Mar 12 2004 aj@suse.de
- Fix sysenter.
- Fix x86 clflush disassembly.
* Wed Mar 10 2004 schwab@suse.de
- Fix a possible race in the PLT.
* Mon Mar  8 2004 aj@suse.de
- Fix cfi testsuite on s390x.
* Mon Mar  8 2004 hare@suse.de
- Enable s390 biarch backend.
- Fix Invalid .insn from gas on s390.
* Mon Mar  8 2004 aj@suse.de
- Fix fde alignment.
* Sat Mar  6 2004 aj@suse.de
- Update to binutils-2.15.90.0.1.1 which incorporates the last two
  changes.
* Fri Mar  5 2004 schwab@suse.de
- Fix align handling.
* Thu Mar  4 2004 aj@suse.de
- Install as manpage.
* Thu Mar  4 2004 aj@suse.de
- Update to binutils-2.15.90.0.1.
* Fri Feb 27 2004 schwab@suse.de
- Support POSIX-compatible argument parsing in ar [#33775].
- Fix textrel patch.
* Thu Feb 26 2004 schwab@suse.de
- Fix spurious DT_TEXTREL.
* Wed Feb 25 2004 matz@suse.de
- Enable new dtags by default.
* Fri Feb 13 2004 hare@suse.de
- Fix memcmp bug in gas/dwarf2dbg.c
* Thu Feb 12 2004 bg@suse.de
- Workaround for ICE in elf32_hppa_relocate_section.
* Thu Jan 15 2004 aj@suse.de
- Fix common page size on ppc.
- Update to binutils 2.14.90.0.8.
* Mon Jan 12 2004 aj@suse.de
- Fix PPC64 TLS bug.
* Fri Dec 12 2003 schwab@suse.de
- Fix file list.
* Tue Dec  2 2003 schwab@suse.de
- Fix last change for ia64.
* Mon Nov 24 2003 aj@suse.de
- Fix handling of '/' in gas on x86 platforms.
* Thu Oct 30 2003 aj@suse.de
- Update to binutils 2.14.90.0.7:
  1. Update from binutils 2003 1029.
  2. Allow type changes for undefined symbols.
  3. Fix EH frame optimization.
  4. Fix the check for undefined versioned symbol with wildcard.
  5. Support generating code for Itanium.
  6. Detect and warn bad symbol index.
  7. Update IPF assemebler DV check.
* Fri Oct 17 2003 schwab@suse.de
- Update dv warning patch once more.
- Disable -Wunused during testsuite.
* Fri Oct 17 2003 schwab@suse.de
- Update dv warning patch.
* Wed Oct 15 2003 aj@suse.de
- Build as non-root user.
* Fri Oct  3 2003 kukuk@suse.de
- Remove tetex from neededforbuild
* Wed Oct  1 2003 schwab@suse.de
- Fix spurious dv conflict warning.
- Don't ignore testsuite failures on ia64.
* Fri Sep 26 2003 aj@suse.de
- Update to binutils-2.14.90.0.6.
* Fri Aug 29 2003 aj@suse.de
- Add patch to speed up linker.
* Tue Aug 19 2003 aj@suse.de
- disable unit-at-a-time for some tests so that they pass (otherwise
  some sections are reordered).
* Fri Aug  8 2003 schwab@suse.de
- Fix generation of efi-app binaries.
* Tue Jul 29 2003 meissner@suse.de
- Fix ppc64 bitmask detection (from current CVS).
* Fri Jul 25 2003 schwab@suse.de
- Readd workaround for missing DESTDIR support.
* Thu Jul 24 2003 aj@suse.de
- Update to binutils 2.14.90.0.5.
* Wed Jul 16 2003 mludvig@suse.cz
- Reverted Alan Modra's patch for .debug_line generation.
  http://sources.redhat.com/ml/binutils/2003-07/msg00294.html
* Fri Jul  4 2003 olh@suse.de
- update to binutils-2.14.90.0.4-cvs20030704.diff.bz2
* Wed Jul  2 2003 olh@suse.de
- add binutils-ppc64-mminimal-toc.patch
  - -disable-nls in cross-binutils, remove man and info to
  avoid file conflicts with multiple cross-binutils packages
* Wed Jul  2 2003 aj@suse.de
- Support z990 instructions.
* Mon Jun 30 2003 olh@suse.de
- add binutils_x86_64_bfd_c90.patch
* Fri Jun 27 2003 olh@suse.de
- update to binutils-2.14.90.0.4-cvs20030627.diff.bz2
  use DESTDIR
* Tue Jun 24 2003 coolo@suse.de
- ignore rpaths only for > 8.2
* Mon Jun 23 2003 coolo@suse.de
- removed %%ifarch mips
* Wed Jun 18 2003 aj@suse.de
- Fix CFI alignment bugs.
* Wed Jun 18 2003 olh@suse.de
- update to binutils-2.14.90.0.4-cvs20030618.diff.bz2
- provide an option to test a vanilla binutils release,
  provide an option to not apply patches that break the testsuite
* Tue Jun 17 2003 coolo@suse.de
- apply the cvs diff on all architectures and sort out the other
  patches
- use %%find_lang
- apply objcopy.c patch to add --only-keep-debug option to strip
  and objcopy
* Fri Jun 13 2003 olh@suse.de
- use binutils-2.14.90.0.4-cvs20030613.diff.bz2 on ppc/ppc64
  to remove the -mminimal-toc requirement on ppc64
* Thu Jun 12 2003 aj@suse.de
- Fix directory file list.
* Thu Jun  5 2003 ro@suse.de
- fix dangling ldscripts symlink for lib64 platforms
* Thu Jun  5 2003 aj@suse.de
- Fix typo in CFI calculation.
- Make .eh_frame section read-only.
- Add more CFI directives.
* Thu Jun  5 2003 coolo@suse.de
- integrating patch to ignore rpaths listed in a file specified
  by $SUSE_IGNORED_RPATHS (supposed to be set to /etc/ld.so.conf)
* Mon Jun  2 2003 aj@suse.de
- Fix addend relocation with CFI.
* Sat May 31 2003 aj@suse.de
- Handle GOT with more than 8191 entries corect on PowerPC.
- Fix dwarf2 CFI bugs.
* Fri May 30 2003 aj@suse.de
- Update to binutils 2.14.90.0.4.
- Improve cfi support.
* Wed May 21 2003 aj@suse.de
- Fix cfi build problems on ia64 and add latest revision of patch.
* Tue May 20 2003 aj@suse.de
- Fix elf visibility problem.
- Add cfi directives.
* Sat May 17 2003 aj@suse.de
- Update to binutils 2.14.90.0.2.
* Thu May 15 2003 aj@suse.de
- Allow testsuite to fail on sparc.
* Wed May 14 2003 schwab@suse.de
- Workaround lack of DESTDIR support.
- Make sure libbfd is installed before libopcodes.
* Wed May 14 2003 aj@suse.de
- Link libopcodes against libbfd.
- Fix package list.
* Mon May 12 2003 aj@suse.de
- Fix bugs and testsuite on s390.
* Wed May  7 2003 aj@suse.de
- Fix bugs in creation of large files.
* Tue May  6 2003 aj@suse.de
- Update to version 2.14.90.0.1.
* Mon Apr 28 2003 schwab@suse.de
- Update ia64 relaxation bug fix.
* Fri Apr 25 2003 aj@suse.de
- Fix ia64 relaxation bugs.
* Thu Apr 24 2003 olh@suse.de
- add binutils-2.13-ppc32-ld-symbol-version.patch
  add binutils-2.13-ppc32-fPIC.patch
    fail to link shared libs compiled without -fPIC
    run make check with -k after this change
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Apr  8 2003 adrian@suse.de
- fix build for mips
* Sat Mar 22 2003 aj@suse.de
- Update to 2.13.0.90.20.
* Wed Mar 19 2003 aj@suse.de
- Do not depend on binutils installation.
* Wed Mar 19 2003 aj@suse.de
- Fix crash in ld with overly long command lines (#23743).
* Thu Feb 27 2003 aj@suse.de
- Package all libiberty include files.
* Wed Feb 19 2003 stepan@suse.de
- add create-cross.sh to easily create cross-binutils packages.
* Tue Feb 18 2003 aj@suse.de
- Run testsuite.
* Fri Feb 14 2003 aj@suse.de
- Fix symbol relocations with versioning.
* Mon Feb 10 2003 aj@suse.de
- Fix real.plt on s390.
* Fri Feb  7 2003 aj@suse.de
- Fix dwarf2 filenames.
* Thu Feb  6 2003 aj@suse.de
- Fix frame header sign extension bug (#23318)
- Fix library path for 64-bit platforms
- Fix x86-64 disassembler.
* Thu Feb  6 2003 stepan@suse.de
- Add alpha TLS patch
* Sat Feb  1 2003 aj@suse.de
- Add sparc TLS patch.
* Sat Jan 25 2003 aj@suse.de
- Update to binutils 2.13.90.0.18 which includes:
  * Fix some ia64 gas bugs.
  * Fix TLS bugs.
  * Fix ELF/ppc bugs.
* Tue Jan 14 2003 bg@suse.de
- add hppa relocation patch from "John David Anglin"
  <dave@hiauly1.hia.nrc.ca>
* Sat Dec 14 2002 adrian@suse.de
- add additional mips64 target on mips
- use mips patches which came with the tar ball on mips
- disable "make check" on mips for now
* Fri Dec  6 2002 schwab@suse.de
- Update to binutils 2.13.90.0.16.
* Wed Dec  4 2002 olh@suse.de
- add ppc64-binutils-ld-makecheck.diff, enable make check on ppc64
* Sat Nov 23 2002 olh@suse.de
- add ppc64-binutils-ld-no256mbsegments.diff
  revert the binutils change that moved text and data into separate
  256M address ranges, at least until the glibc dynamic loader
  can handle such binaries gracefully.
* Tue Nov  5 2002 bg@suse.de
- Enable hppa build
- Add support for hppa64
* Thu Oct 24 2002 aj@suse.de
- Fix allocation of orphaned sections to aviod problems with strip.
- Fix another problem on alpha with orphaned sections.
* Tue Oct 15 2002 aj@suse.de
- Install libiberty.h [Fixes #20941].
* Mon Oct 14 2002 aj@suse.de
- Update to binutils-2.13.90.0.10.
* Tue Oct  1 2002 aj@suse.de
- Update to binutils-2.13.90.0.5.
- Add tls support for x86-64.
- Fix tls support for i386.
* Mon Sep 16 2002 schwab@suse.de
- Enable use of brl for out of range branch fixup.
* Sun Sep  1 2002 aj@suse.de
- Fix LIB_PATH for x86_64.
* Fri Aug 30 2002 bk@suse.de
- enable s390 as additional target on s390x
- fix LIB_PATH for elf_s390 emulation to not use lib64 paths
- fix LIB_PATH for elf64_s390 to include /usr/local/lib64 and /lib64
- delete -fsigned-char for binutils on s390/s390x
* Tue Aug 27 2002 aj@suse.de
- Fix x86-64 gotpcrel generation.
- Add fix for bugs in gas on i386 where GOT references where
  miscompiled and fix problem with absolute section.
- Fix reference counting on various platforms.
- Fix counting of definitions in shared objects
* Fri Jul 19 2002 schwab@suse.de
- Update to binutils 2.12.90.0.15.
* Sat Jul 13 2002 schwab@suse.de
- Add fix for ia64 indirect call encoding bug.
* Thu Jul 11 2002 aj@suse.de
- Fix generation of nops for x86-64.
* Wed Jul 10 2002 aj@suse.de
- Fix -ffunction sections.
* Tue Jul  9 2002 olh@suse.de
- add patches for gas biarch support on ppc
  binutils-2.12.90.0.14-cvs.diff 20020709
  binutils_ppc_biarch_gas.diff
  binutils_ppc_biarch_gas_weaksym.diff
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Wed Jul  3 2002 aj@suse.de
- Update to binutils 2.12.90.0.14.
- Remove patches that have been integrated.
* Tue Jul  2 2002 bk@suse.de
- add fixes for s390(x) - should make this version work for s390.
* Wed Jun 26 2002 aj@suse.de
- Do not discard empty sections (otherwise the kernel build will
  break).
* Thu Jun 20 2002 adrian@suse.de
- Update to binutils 2.12.90.0.12.
  * Update from binutils 2002 0618.
  * Fix an mips assembler bug.
- remove s390-testsuite.patch, it is inside 2.12.90.0.12 now
* Mon Jun 17 2002 aj@suse.de
- Abort with error message if shared libs are build without -fPIC
  on x86-64 (in cases where this can be detected).
- Remove ld -Y patch.
* Fri Jun 14 2002 olh@suse.de
- use _target_cpu in diff packagelist
* Wed Jun 12 2002 aj@suse.de
- Update to binutils 2.12.90.0.11.
- Better handle ld -Y with multilibs.
- Do not link 32-bit and 64-bit objects togethers when searching libs
  via ld.so.conf.
- Add x86-64 as target for i386.
* Fri May 31 2002 olh@suse.de
- update cvs patch to 20020531, obsolets ppc64_binutils.diff
  disable make check on ppc64
* Thu May 30 2002 olh@suse.de
- add binutils_x86_64_testsuite.diff, selective[1245] xfail on x86-64
* Wed May 29 2002 olh@suse.de
- add ppc64_binutils.diff, for libtool
  nm -B output, use D instead of ? for function descriptors
* Mon May 27 2002 olh@suse.de
- update cvs patch to 20020527
* Thu May 23 2002 olh@suse.de
- add cvs 20020523 diff for ppc/ppc64
  put readelf manpage in filelist
* Sun May 19 2002 olh@suse.de
- handle elf64 (powerpc64-suse-linux) on ppc32
* Fri May 17 2002 adrian@suse.de
- fix build for s390x and mips
  (added pic config file)
- do not ignore return value of "make check" on mips anymore
* Fri May 17 2002 schwab@suse.de
- Add gprof docs.
- Add message catalogues.
* Fri May 17 2002 uli@suse.de
- added gprof to file list
* Mon May 13 2002 schwab@suse.de
- Add PIC configuration for x86-64.
* Mon May 13 2002 olh@suse.de
- update to 2.12.90.0.7
* Sun May 12 2002 schwab@suse.de
- Install the PIC libiberty.a.
* Fri May 10 2002 meissner@suse.de
- x86-64 relocation conversion should not just convert to
  64bit relocations since we sometimes do have 32bit ones.
  (Patch from Andreas Schwab.)
* Tue Apr 23 2002 aj@suse.de
- Fix a bug with --eh-frame-hdr that occured on sparc.
* Mon Apr 22 2002 aj@suse.de
- Fix testsuite for alpha and s390.
- Fix --eh-frame-hdr.
- Update x86-64 assembler patch.
* Sat Apr 20 2002 schwab@suse.de
- Fix pcrel handling in x86-64 assembler.
* Wed Apr 17 2002 aj@suse.de
- Fix merging of s390 sections.
* Mon Apr 15 2002 aj@suse.de
- Fix PPC linker bug.
* Fri Apr 12 2002 aj@suse.de
- Update to binutils-2.12.90.0.4:
  * Contains x86-64 fix
  * Fixes S390 ld failure
  * Fixes for sparc
* Mon Apr  8 2002 aj@suse.de
- Add fix for pcrel relocations for x86-64.
* Tue Apr  2 2002 aj@suse.de
- Change platforms where testsuite is run.
* Mon Mar 25 2002 schwab@suse.de
- Update to binutils-2.12.90.0.3.
* Sun Mar 10 2002 schwab@suse.de
- Update to binutils-2.12.90.0.1.
- gprof now supported on MIPS.
* Thu Feb 28 2002 stepan@suse.de
- add data segment alignment patches.
* Mon Feb 25 2002 schwab@suse.de
- Add fix for elf64-ia64 linker scripts.
* Mon Feb 18 2002 schwab@suse.de
- Fix broken patch.
* Mon Feb 18 2002 aj@suse.de
- Update to binutils-2.11.93.0.2.
* Thu Feb 14 2002 aj@suse.de
- Fix bug in handling of version maps by ld.  This is needed for
  GCC 3.1.
* Mon Nov 26 2001 aj@suse.de
- gprof is not supported on MIPS, don't try to package it.
* Thu Nov 15 2001 adrian@suse.de
- ignore known problem on mips in testsuite
- disable combreloc patch for mips
* Wed Nov 14 2001 ro@suse.de
- added include file symcat.h to filelist
* Mon Nov 12 2001 aj@suse.de
- Update to binutils-2.11.92.0.10.
* Sun Sep 30 2001 schwab@suse.de
- Update to  binutils 2.11.90.0.31.
- Add support for @iplt and .data16 on ia64.
* Mon Sep  3 2001 aj@suse.de
- Fix relative relocations on Alpha.
* Thu Aug 30 2001 aj@suse.de
- Update to binutils 2.11.90.0.29.  It includes support for 64-bit
  PowerPC.
* Mon Aug 27 2001 aj@suse.de
- Update to current CVS version and include patch to always enable
  sorting of relocations.  Together with the new glibc this reduces
  relocation processing at program startup significantly.
* Wed Aug 22 2001 aj@suse.de
- Use AltiVec/PPC patch.
- Revert objdump patch that causes sparc kernel build failure.
- Add missing s390 jump instructions.
- Fix bug with unaligned accesses in the sparc assembler.
* Fri Aug 17 2001 egger@suse.de
- Added patch for missing AltiVec/PPC opcodes.
* Thu Aug 16 2001 aj@suse.de
- Update to 2.11.90.0.27, fix s390 relocation generation.
* Tue Jul 17 2001 aj@suse.de
- Update to binutils 2.11.90.0.24.
* Wed Jul 11 2001 aj@suse.de
- Update to binutils 2.11.90.0.23.
* Wed Jun 13 2001 aj@suse.de
- Run testsuite on s390.
* Tue Jun 12 2001 aj@suse.de
- Update to binutils 2.11.90.0.15.
* Mon May 14 2001 aj@suse.de
- Update to binutils 2.11.90.0.8.
* Mon May  7 2001 aj@suse.de
- Update to latest version.
* Thu Mar 29 2001 aj@suse.de
- Fix a relaxation bug on ia32 that occurs while building GCC.
* Tue Mar 27 2001 aj@suse.de
- Test for alpha instead of axp.
* Mon Mar 26 2001 aj@suse.de
- Add patch for S390 to fix relocs.
* Mon Mar 26 2001 aj@suse.de
- The testsuite is broken on axp, disable it.
* Thu Mar  8 2001 aj@suse.de
- Use separate build directory, don't run testsuite on sparc.
* Mon Mar  5 2001 aj@suse.de
- Update to 2.10.91.0.4.
* Thu Feb 22 2001 aj@suse.de
- Run the testsuite on some platforms.
* Tue Feb 20 2001 aj@suse.de
- Add sparc fix for weak symbols.
* Mon Feb 19 2001 aj@suse.de
- Update to 2.10.91.0.2.
* Thu Nov 16 2000 aj@suse.de
- Added an alpha patch to fix glibc problems.
* Mon Oct 23 2000 aj@suse.de
- Update to 2.10.0.33.
- Remove PPC patch since it's solved better in .33.
* Sun Oct 15 2000 kukuk@suse.de
- Update to binutils 2.10.0.31
- Port s390 patches
- Add PPC patch to fix glibc 2.2 problems
* Thu Sep 14 2000 kukuk@suse.de
- Use macros in spec file
* Tue Aug 29 2000 aj@suse.de
- New version 2.10.0.24 with additional s390 patches.
* Sun Apr 16 2000 ro@suse.de
- added alpha3.dif to fix another problem with compaq compilers
* Sat Mar 18 2000 aj@suse.de
- Fix problems with Compaq compiler, see:
  http://sourceware.cygnus.com/ml/binutils/2000-03/msg00226.html
  http://sourceware.cygnus.com/ml/binutils/2000-03/msg00160.html
* Mon Mar 13 2000 aj@suse.de
- Added readelf to file list.
* Mon Feb 28 2000 ro@suse.de
- fix HOST macro
- added alpha fix from Andrea
* Thu Jan 20 2000 aj@suse.de
- New version 2.9.5.0.24.
* Thu Dec  9 1999 ro@suse.de
- leave targets for now
* Wed Dec  8 1999 kasal@suse.de
- added buildroot
  (it required a patch to target ld/Makefile.am, target install-data-local)
* Tue Nov 23 1999 kasal@suse.de
- backported sparc patch from cvs version of binutils
- added note that geo@suse.cz can make NLMs
* Tue Nov 16 1999 kukuk@suse.de
- Remove broken Sparc as patch, add bfd patch for sparc32
* Wed Nov 10 1999 kukuk@suse.de
- spec file cleanup, add support for Sparc
- Remove dependency for bin86, not longer necessary
* Tue Nov  9 1999 uli@suse.de
- added PPC-specific files to %%files section
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 24 1999 uli@suse.de
- fixed Makefile.Linux for PPC
* Fri May 28 1999 ro@suse.de
- update to .25
* Thu Apr  8 1999 ro@suse.de
- update to .23
* Mon Mar 29 1999 ro@suse.de
- remove hacks and install libiberty.a in /usr/lib
* Sun Mar 14 1999 ro@suse.de
- libtool tries to be smart dropping the link -liberty
  try to be smarter: changed "-liberty" to "../libiberty/libiberty.a"
* Fri Mar  5 1999 ro@suse.de
- update to 2.9.1.0.22b FOR NOW AXP ONLY
- libnaming changed
* Fri Feb 19 1999 ro@suse.de
- update to 2.9.1.0.20
* Mon Jan 11 1999 ro@suse.de
- adapted specfile to build on alpha, too
- added ansidecl.h to filelist for glibc
* Mon Nov  2 1998 ro@suse.de
- update to 2.9.1.0.15
* Fri Sep 11 1998 ro@suse.de
- switch detection of GLIBC to automake
* Tue Jul  7 1998 ro@suse.de
- pack files depending on used libc / compile a.out for libc5
* Wed May 20 1998 bs@suse.de
- took c++filt off from file list (is included in egcs)
* Wed May  6 1998 florian@suse.de
- update to binutils 2.9.1.0.4
* Tue Jul 29 1997 florian@suse.de
- the a.out-assembler was not installed correctly by "make install"
* Wed Jun 25 1997 florian@suse.de
- add bug-fixes from gnu.utils.bugs
* Sun Jun  8 1997 florian@suse.de
- always remove /usr/bin/encaps
* Sun Jun  8 1997 florian@suse.de
- update to version 2.8.1 with fixes by H.J. Lu
* Thu Jan  2 1997 florian@suse.de
- Update auf Version 2.7.0.3. Sollte jetzt als normales binutils-Paket
  installiert sein. 2.6.* hoechstens unter unsorted...
